import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 数据字典服务对象基类
 *
 * @export
 * @class IBZDictServiceBase
 * @extends {EntityServie}
 */
export default class IBZDictServiceBase extends EntityService {

    /**
     * Creates an instance of  IBZDictServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  IBZDictServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof IBZDictServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='ibzdict';
        this.APPDEKEY = 'dictid';
        this.APPDENAME = 'ibzdicts';
        this.APPDETEXT = 'dictname';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZDictServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().get(`/ibzdicts/${context.ibzdict}/select`,isloading);
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZDictServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = await Http.getInstance().get(`/ibzdicts/${context.ibzdict}`,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_ibzdictitems',JSON.stringify(res.data.ibzdictitems));
            return res;

    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZDictServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let ibzdictitemsData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_ibzdictitems'),'undefined')){
            ibzdictitemsData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_ibzdictitems') as any);
        }
        masterData.ibzdictitems = ibzdictitemsData;
        Object.assign(data,masterData);
        data[this.APPDEKEY] = null;
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/ibzdicts`,data,isloading);
        this.tempStorage.setItem(tempContext.srfsessionkey+'_ibzdictitems',JSON.stringify(res.data.ibzdictitems));
        return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZDictServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().post(`/ibzdicts/${context.ibzdict}/checkkey`,data,isloading);
    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZDictServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any = await  Http.getInstance().get(`/ibzdicts/getdraft`,isloading);
        res.data.ibzdict = data.ibzdict;
            this.tempStorage.setItem(context.srfsessionkey+'_ibzdictitems',JSON.stringify(res.data.ibzdictitems));
        return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZDictServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let ibzdictitemsData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_ibzdictitems'),'undefined')){
            ibzdictitemsData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_ibzdictitems') as any);
        }
        masterData.ibzdictitems = ibzdictitemsData;
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/ibzdicts/${context.ibzdict}`,data,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_ibzdictitems',JSON.stringify(res.data.ibzdictitems));
            return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZDictServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().delete(`/ibzdicts/${context.ibzdict}`,isloading);

    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZDictServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let ibzdictitemsData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_ibzdictitems'),'undefined')){
            ibzdictitemsData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_ibzdictitems') as any);
        }
        masterData.ibzdictitems = ibzdictitemsData;
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/ibzdicts/${context.ibzdict}/save`,data,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_ibzdictitems',JSON.stringify(res.data.ibzdictitems));
            return res;
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof IBZDictServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/ibzdicts/fetchdefault`,tempData,isloading);
    }
}